#!/bin/bash
USER=/home/intel

cd $USER
sudo docker rmi media-analytics-pipeline-zoo
